@@ -3,54 +3,49 @@ This is a convenience wrapper for dictionaries
 returned from LDAP servers containing attribute
 names of variable case.
 
-See http://www.python-ldap.org/ for details.
-
-$Id: cidict.py,v 1.13 2009/04/17 14:34:34 stroeder Exp $
+See https://www.python-ldap.org/ for details.
 """
 
-__version__ = """$Revision: 1.13 $"""
+from ldap import __version__
 
-from UserDict import UserDict
-from string import lower
+from ldap.compat import IterableUserDict
 
-class cidict(UserDict):
+
+class cidict(IterableUserDict):
   """
   Case-insensitive but case-respecting dictionary.
   """
 
   def __init__(self,default=None):
     self._keys = {}
-    UserDict.__init__(self,{})
+    IterableUserDict.__init__(self,{})
     self.update(default or {})
 
   def __getitem__(self,key):
-    return self.data[lower(key)]
+    return self.data[key.lower()]
 
   def __setitem__(self,key,value):
-    lower_key = lower(key)
+    lower_key = key.lower()
     self._keys[lower_key] = key
     self.data[lower_key] = value
 
   def __delitem__(self,key):
-    lower_key = lower(key)
+    lower_key = key.lower()
     del self._keys[lower_key]
     del self.data[lower_key]
 
   def update(self,dict):
-    for key in dict.keys():
-      self[key] = dict[key]
+    for key, value in dict.items():
+      self[key] = value
 
   def has_key(self,key):
-    return UserDict.has_key(self,lower(key))
+    return key in self
 
   def __contains__(self,key):
-    return self.has_key(key)
+    return IterableUserDict.__contains__(self, key.lower())
 
-  def get(self,key,failobj=None):
-    try:
-      return self[key]
-    except KeyError:
-      return failobj
+  def __iter__(self):
+    return iter(self.keys())
 
   def keys(self):
     return self._keys.values()
@@ -73,7 +68,7 @@ def strlist_minus(a,b):
   result = [
     elt
     for elt in a
-    if not temp.has_key(elt)
+    if elt not in temp
   ]
   return result
 
@@ -88,7 +83,7 @@ def strlist_intersection(a,b):
   result = [
     temp[elt]
     for elt in b
-    if temp.has_key(elt)
+    if elt in temp
   ]
   return result
 
@@ -103,23 +98,3 @@ def strlist_union(a,b):
   for elt in b:
     temp[elt] = elt
   return temp.values()
-
-
-if __debug__ and __name__ == '__main__':
-  x = { 'AbCDeF' : 123 }
-  cix = cidict(x)
-  assert cix["ABCDEF"] == 123
-  assert cix.get("ABCDEF",None) == 123
-  assert cix.get("not existent",None) is None
-  cix["xYZ"] = 987
-  assert cix["XyZ"] == 987
-  assert cix.get("XyZ",None) == 987
-  cix_keys = cix.keys()
-  cix_keys.sort()
-  assert cix_keys==['AbCDeF','xYZ'],ValueError(repr(cix_keys))
-  cix_items = cix.items()
-  cix_items.sort()
-  assert cix_items==[('AbCDeF',123),('xYZ',987)],ValueError(repr(cix_items))
-  del cix["abcdEF"]
-  assert not cix._keys.has_key("abcdef")
-  assert not cix.has_key("AbCDef")
